@@ -29,6 +29,7 @@ from neutron.plugins.ml2 import rpc as ml2_rpc
 from neutron.tests.common import helpers
 
 from neutron_lib.api.definitions import portbindings
+from neutron_lib.callbacks import events
 from neutron_lib import constants as const
 from neutron_lib import context as n_context
 from neutron_lib.plugins import directory
@@ -711,11 +712,12 @@ class TestBagpipeServiceDriverCallbacks(TestBagpipeCommon,
             self.mock_attach_rpc.reset_mock()
             self.mock_detach_rpc.reset_mock()
 
+            payload = events.DBEventPayload(
+                self.ctxt, resource_id=port['port']['id'],
+                metadata={}, states=[port['port']])
+
             self.bagpipe_driver.registry_port_deleted(
-                None, None, None,
-                context=self.ctxt,
-                port_id=port['port']['id']
-            )
+                None, None, None, payload)
             self.assertFalse(self.mock_attach_rpc.called)
             self.assertFalse(self.mock_detach_rpc.called)
 
@@ -754,11 +756,12 @@ class TestBagpipeServiceDriverCallbacks(TestBagpipeCommon,
             self.mock_attach_rpc.reset_mock()
             self.mock_detach_rpc.reset_mock()
 
+            payload = events.DBEventPayload(
+                self.ctxt, resource_id=port['port']['id'],
+                metadata={}, states=[port['port']])
+
             self.bagpipe_driver.registry_port_deleted(
-                None, None, None,
-                context=self.ctxt,
-                port_id=port['port']['id']
-            )
+                None, None, None, payload)
             self.assertFalse(self.mock_attach_rpc.called)
             self.assertFalse(self.mock_detach_rpc.called)
 
@@ -793,11 +796,12 @@ class TestBagpipeServiceDriverCallbacks(TestBagpipeCommon,
                                   return_value=[{
                                       'bgpvpn_id': bgpvpn['bgpvpn']['id']
                                   }]).start():
+
+            payload = events.DBEventPayload(
+                self.ctxt, resource_id=router['router']['id'],
+                metadata={'port': {'network_id': net['network']['id']}})
             self.bagpipe_driver.registry_router_interface_created(
-                None, None, None,
-                context=self.ctxt,
-                port={'network_id': net['network']['id']},
-                router_id=router['router']['id'],
+                None, None, None, payload=payload
             )
             self.mock_update_rpc.assert_called_once_with(
                 mock.ANY,
@@ -818,12 +822,16 @@ class TestBagpipeServiceDriverCallbacks(TestBagpipeCommon,
                                   return_value=[{
                                       'bgpvpn_id': bgpvpn['bgpvpn']['id']
                                   }]).start():
+            payload = events.DBEventPayload(
+                self.ctxt, metadata={
+                    'network_id': port['port']['network_id'],
+                    'port': {
+                        'device_id': router['router']['id'],
+                        'network_id': net['network']['id']}
+                })
             self.bagpipe_driver.registry_router_interface_deleted(
                 None, None, None,
-                context=self.ctxt,
-                network_id=port['port']['network_id'],
-                port={'device_id': router['router']['id'],
-                      'network_id': net['network']['id']}
+                payload=payload
             )
             self.mock_delete_rpc.assert_called_once_with(
                 mock.ANY,
@@ -982,11 +990,12 @@ class TestBagpipeServiceDriverCallbacks(TestBagpipeCommon,
 
     def test_exception_on_callback(self):
         with mock.patch.object(bagpipe.LOG, 'exception') as log_exc:
-            self.bagpipe_driver.registry_port_updated(
-                None, None, None,
-                context=self.ctxt,
-                port=None
-            )
+            payload = events.DBEventPayload(
+                self.ctxt, resource_id=None,
+                metadata={}, states=[])
+
+            self.bagpipe_driver.registry_port_deleted(
+                None, None, None, payload)
             self.assertFalse(self.mock_attach_rpc.called)
             self.assertFalse(self.mock_detach_rpc.called)
             self.assertTrue(log_exc.called)
@@ -1020,13 +1029,13 @@ class TestBagpipeServiceDriverCallbacks(TestBagpipeCommon,
             }
         }
 
-        self.assertItemsEqual(result['l3vpn']['import_rt'],
+        self.assertCountEqual(result['l3vpn']['import_rt'],
                               expected['l3vpn']['import_rt'])
-        self.assertItemsEqual(result['l3vpn']['export_rt'],
+        self.assertCountEqual(result['l3vpn']['export_rt'],
                               expected['l3vpn']['export_rt'])
-        self.assertItemsEqual(result['l2vpn']['import_rt'],
+        self.assertCountEqual(result['l2vpn']['import_rt'],
                               expected['l2vpn']['import_rt'])
-        self.assertItemsEqual(result['l2vpn']['export_rt'],
+        self.assertCountEqual(result['l2vpn']['export_rt'],
                               expected['l2vpn']['export_rt'])
 
 
