@@ -15,7 +15,8 @@
 
 import contextlib
 import copy
-import mock
+from unittest import mock
+
 import webob.exc
 
 from neutron_lib.plugins import directory
@@ -24,6 +25,7 @@ from oslo_utils import uuidutils
 from neutron.api import extensions as api_extensions
 from neutron.db import servicetype_db as sdb
 from neutron import extensions as n_extensions
+from neutron.services import provider_configuration as pconfig
 from neutron.tests.unit.db import test_db_base_plugin_v2
 from neutron.tests.unit.extensions import test_l3
 from neutron.tests.unit.extensions.test_l3 import TestL3NatServicePlugin
@@ -48,8 +50,8 @@ def http_client_error(req, res):
 
 class TestBgpvpnDriverWithVni(driver_api.BGPVPNDriverRC):
     more_supported_extension_aliases = (
-        driver_api.BGPVPNDriverRC.more_supported_extension_aliases +
-        [bgpvpn_vni_def.ALIAS])
+        driver_api.BGPVPNDriverRC.more_supported_extension_aliases + [
+            bgpvpn_vni_def.ALIAS])
 
     def __init__(self, *args, **kwargs):
         super(TestBgpvpnDriverWithVni, self).__init__(*args, **kwargs)
@@ -81,6 +83,11 @@ class BgpvpnTestCaseMixin(test_db_base_plugin_v2.NeutronDbPluginV2TestCase,
                               'get_service_providers').start())
         self.service_providers.return_value = [provider]
 
+        self.provider_configuration = (
+            mock.patch.object(pconfig.ProviderConfiguration,
+                              '__init__').start())
+        self.provider_configuration.return_value = None
+
         bgpvpn_plugin_str = ('networking_bgpvpn.neutron.services.plugin.'
                              'BGPVPNPlugin')
         l3_plugin_str = ('neutron.tests.unit.extensions.test_l3.'
@@ -800,8 +807,7 @@ class TestBGPVPNServiceDriverDB(BgpvpnTestCaseMixin):
         super(TestBGPVPNServiceDriverDB, self).setUp()
 
     def _raise_bgpvpn_driver_precommit_exc(self, *args, **kwargs):
-            raise extensions.bgpvpn.BGPVPNDriverError(
-                method='precommit method')
+        raise extensions.bgpvpn.BGPVPNDriverError(method='precommit method')
 
     @mock.patch.object(driver_api.BGPVPNDriver,
                        'create_bgpvpn_postcommit')
